@@ -4,6 +4,7 @@ import tornado.web
 import tornado.websocket
 import json
 import os
+import asyncio
 
 from threading import Lock
 
@@ -30,6 +31,11 @@ class GithubWebhook(object):
         s.status_websockets = set()
         s.ioloop = tornado.ioloop.IOLoop.current(True)
 
+        # allow any thread to creat an event loop.
+        # Prevents this:
+        #    RuntimeError: There is no current event loop in thread 'Thread-1'.
+        asyncio.set_event_loop_policy(tornado.platform.asyncio.AnyThreadEventLoopPolicy())
+
     def run(s):
         log.info("tornado IOLoop started.")
         s.ioloop.start()
